@@ -30,6 +30,8 @@ from .cerebras import CerebrasInstrumentation
 from .milvus import MilvusInstrumentation
 from .google_genai import GoogleGenaiInstrumentation
 from .graphlit import GraphlitInstrumentation
+from .phidata import PhiDataInstrumentation
+from .agno import AgnoInstrumentation
 
 __all__ = [
     "AnthropicInstrumentation",
@@ -61,4 +63,6 @@ __all__ = [
     "GoogleGenaiInstrumentation",
     "CrewaiToolsInstrumentation",
     "GraphlitInstrumentation",
+    "PhiDataInstrumentation",
+    "AgnoInstrumentation",
 ]
